@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-08 14:02:33
-# @Last Modified time: 2020-10-22 16:24:00
+# @Last Modified time: 2022-11-14 14:35:57
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -10,7 +10,8 @@
 from .redshift import RedshiftDB
 from .sqlite import SqliteDB
 from .mysql import MysqlDB
-from .snowflake import SnowflakeDB
+# from .snowflake import SnowflakeDB
+from .trino import TrinoDB
 
 __doc__ = "数据库接口"
-__all__ = ['RedshiftDB', 'SqliteDB', 'MysqlDB', 'SnowflakeDB']
+__all__ = ['RedshiftDB', 'SqliteDB', 'MysqlDB', 'TrinoDB']
